=== modified file 'handler/chatstartingjob.cpp'
--- handler/chatstartingjob.cpp	2016-07-07 23:46:27 +0000
+++ handler/chatstartingjob.cpp	2016-07-08 02:07:04 +0000
@@ -27,10 +27,12 @@
 #include <TelepathyQt/PendingChannelRequest>
 
 ChatStartingJob::ChatStartingJob(TextHandler *textHandler, const QString &accountId, const QVariantMap &properties)
-: MessageJob(new ChatStartingJobAdaptor(this), textHandler), mTextHandler(textHandler), mAccountId(accountId), mProperties(properties)
+: MessageJob(textHandler), mTextHandler(textHandler), mAccountId(accountId), mProperties(properties)
 {
     qDebug() << __PRETTY_FUNCTION__;
     connect(this, &ChatStartingJob::textChannelChanged, &ChatStartingJob::channelObjectPathChanged);
+
+    setAdaptorAndRegister(new ChatStartingJobAdaptor(this));
 }
 
 QString ChatStartingJob::accountId()

=== modified file 'handler/messagejob.cpp'
--- handler/messagejob.cpp	2016-07-07 22:16:11 +0000
+++ handler/messagejob.cpp	2016-07-08 02:07:04 +0000
@@ -27,9 +27,20 @@
 #include <QTimer>
 #include <QDebug>
 
-MessageJob::MessageJob(QDBusAbstractAdaptor *adaptor, QObject *parent)
-: QObject(parent), mStatus(Pending), mFinished(false), mAdaptor(adaptor)
-{
+MessageJob::MessageJob(QObject *parent)
+: QObject(parent), mStatus(Pending), mFinished(false), mAdaptor(0)
+{
+}
+
+MessageJob::~MessageJob()
+{
+    HandlerDBus::instance()->unregisterObject(mObjectPath);
+}
+
+void MessageJob::setAdaptorAndRegister(QDBusAbstractAdaptor *adaptor)
+{
+    mAdaptor = adaptor;
+
     static ulong count = 0;
     // just to avoid overflowing
     if (count == ULONG_MAX) {
@@ -38,11 +49,6 @@
     mObjectPath = HandlerDBus::instance()->registerObject(this, QString("messagejob%1").arg(count++));
 }
 
-MessageJob::~MessageJob()
-{
-    HandlerDBus::instance()->unregisterObject(mObjectPath);
-}
-
 MessageJob::Status MessageJob::status() const
 {
     return mStatus;

=== modified file 'handler/messagejob.h'
--- handler/messagejob.h	2016-07-07 22:16:11 +0000
+++ handler/messagejob.h	2016-07-08 02:07:04 +0000
@@ -43,9 +43,11 @@
         Failed
     };
 
-    explicit MessageJob(QDBusAbstractAdaptor *adaptor, QObject *parent = 0);
+    explicit MessageJob(QObject *parent = 0);
     virtual ~MessageJob();
 
+    void setAdaptorAndRegister(QDBusAbstractAdaptor *adaptor);
+
     Status status() const;
     bool isFinished() const;
 

=== modified file 'handler/messagesendingjob.cpp'
--- handler/messagesendingjob.cpp	2016-07-07 23:14:08 +0000
+++ handler/messagesendingjob.cpp	2016-07-08 02:07:04 +0000
@@ -59,8 +59,9 @@
  </smil>"
 
 MessageSendingJob::MessageSendingJob(TextHandler *textHandler, PendingMessage message)
-: MessageJob(new MessageSendingJobAdaptor(this), textHandler), mTextHandler(textHandler), mMessage(message), mFinished(false)
+: MessageJob(textHandler), mTextHandler(textHandler), mMessage(message), mFinished(false)
 {
+    setAdaptorAndRegister(new MessageSendingJobAdaptor(this));
 }
 
 MessageSendingJob::~MessageSendingJob()
@@ -98,6 +99,7 @@
     if (!account) {
         setStatus(Failed);
         scheduleDeletion();
+        return;
     }
 
     setStatus(Running);

